@@ -49,26 +49,10 @@
 static char *emblems[] = {"dropbox-uptodate", "dropbox-syncing", "dropbox-unsyncable"};
 gchar *DEFAULT_EMBLEM_PATHS[2] = { EMBLEMDIR , NULL };
 
-gboolean dropbox_use_caja_submenu_workaround;
 gboolean dropbox_use_operation_in_progress_workaround;
 
 static GType dropbox_type = 0;
 
-/* for old versions of glib */
-#if 0  // Silence Warnings.
-static void my_g_hash_table_get_keys_helper(gpointer key,
-					    gpointer value,
-					    GList **ud) {
-  *ud = g_list_append(*ud, key);
-}
-
-static GList *my_g_hash_table_get_keys(GHashTable *ght) {
-  GList *list = NULL;
-  g_hash_table_foreach(ght, (GHFunc) my_g_hash_table_get_keys_helper, &list);
-  return list;
-}
-#endif
-
 /* probably my favorite function */
 static gchar *
 canonicalize_path(gchar *path) {
@@ -596,13 +580,6 @@ caja_dropbox_parse_menu(gchar			**options,
 	g_object_set_property (G_OBJECT(item), "sensitive", &sensitive);
       }
 
-      /* taken from caja-file-repairer (http://repairer.kldp.net/):
-       * this code is a workaround for a bug of caja
-       * See: http://bugzilla.gnome.org/show_bug.cgi?id=508878 */
-      if (dropbox_use_caja_submenu_workaround) {
-	toret = g_list_append(toret, item);
-      }
-
       g_object_unref(item);
       g_string_free(new_action_string, TRUE);
       ret++;
